@@ -29,7 +29,10 @@ QByteArray FakeServer::greeting()
     return "S: * OK localhost Test Library server ready";
 }
 
-FakeServer::FakeServer(QObject *parent) : QThread(parent), m_encrypted(false), m_starttls(false)
+FakeServer::FakeServer(QObject *parent)
+    : QThread(parent)
+    , m_encrypted(false)
+    , m_starttls(false)
 {
     moveToThread(this);
 }
@@ -51,7 +54,7 @@ void FakeServer::dataAvailable()
 {
     QMutexLocker locker(&m_mutex);
 
-    auto *socket = qobject_cast<QTcpSocket *>(sender());
+    auto socket = qobject_cast<QTcpSocket *>(sender());
     QVERIFY(socket);
 
     int scenarioNumber = m_clientSockets.indexOf(socket);
@@ -96,7 +99,6 @@ void FakeServer::setWaitForStartTls(bool wait)
     m_waitForStartTls = wait;
 }
 
-
 void FakeServer::run()
 {
     if (m_encrypted) {
@@ -173,7 +175,7 @@ bool FakeServer::isAllScenarioDone() const
 {
     QMutexLocker locker(&m_mutex);
 
-    foreach (const QList<QByteArray> &scenario, m_scenarios) {
+    for (const QList<QByteArray> &scenario : qAsConst(m_scenarios)) {
         if (!scenario.isEmpty()) {
             return false;
         }
@@ -187,8 +189,7 @@ void FakeServer::writeServerPart(int scenarioNumber)
     QList<QByteArray> scenario = m_scenarios[scenarioNumber];
     QTcpSocket *clientSocket = m_clientSockets[scenarioNumber];
 
-    while (!scenario.isEmpty() &&
-            (scenario.first().startsWith("S: ") || scenario.first().startsWith("W: "))) {
+    while (!scenario.isEmpty() && (scenario.first().startsWith("S: ") || scenario.first().startsWith("W: "))) {
         QByteArray rule = scenario.takeFirst();
 
         if (rule.startsWith("S: ")) {
@@ -200,8 +201,7 @@ void FakeServer::writeServerPart(int scenarioNumber)
         }
     }
 
-    if (!scenario.isEmpty() &&
-            scenario.first().startsWith("X")) {
+    if (!scenario.isEmpty() && scenario.first().startsWith("X")) {
         scenario.takeFirst();
         clientSocket->close();
     }
@@ -224,8 +224,7 @@ void FakeServer::readClientPart(int scenarioNumber)
     QList<QByteArray> scenario = m_scenarios[scenarioNumber];
     KIMAP::ImapStreamParser *clientParser = m_clientParsers[scenarioNumber];
 
-    while (!scenario.isEmpty() &&
-            scenario.first().startsWith("C: ")) {
+    while (!scenario.isEmpty() && scenario.first().startsWith("C: ")) {
         QByteArray received = "C: " + clientParser->readUntilCommandEnd().trimmed();
         QByteArray expected = scenario.takeFirst();
         if (expected.contains("C: SKIP")) {
