@@ -6,15 +6,14 @@
 
 #include "fetchjob.h"
 
-#include <QTimer>
 #include "kimap_debug.h"
 #include <KLocalizedString>
+#include <QTimer>
 
 #include "job_p.h"
 #include "response_p.h"
 #include "session_p.h"
 
-
 namespace KIMAP
 {
 class FetchJobPrivate : public JobPrivate
@@ -23,10 +22,12 @@ public:
     FetchJobPrivate(FetchJob *job, Session *session, const QString &name)
         : JobPrivate(session, name)
         , q(job)
-    { }
+    {
+    }
 
     ~FetchJobPrivate()
-    { }
+    {
+    }
 
     void parseBodyStructure(const QByteArray &structure, int &pos, KMime::Content *content);
     void parsePart(const QByteArray &structure, int &pos, KMime::Content *content);
@@ -43,27 +44,16 @@ public:
         Q_EMIT q->messagesAvailable(pendingMsgs);
 
         if (!pendingParts.isEmpty()) {
-            Q_EMIT q->partsReceived(selectedMailBox,
-                                  pendingUids, pendingParts);
-            Q_EMIT q->partsReceived(selectedMailBox,
-                                  pendingUids, pendingAttributes,
-                                  pendingParts);
+            Q_EMIT q->partsReceived(selectedMailBox, pendingUids, pendingParts);
+            Q_EMIT q->partsReceived(selectedMailBox, pendingUids, pendingAttributes, pendingParts);
         }
         if (!pendingSizes.isEmpty() || !pendingFlags.isEmpty() || !pendingMessages.isEmpty()) {
-            Q_EMIT q->headersReceived(selectedMailBox,
-                                    pendingUids, pendingSizes,
-                                    pendingFlags, pendingMessages);
-            Q_EMIT q->headersReceived(selectedMailBox,
-                                    pendingUids, pendingSizes,
-                                    pendingAttributes, pendingFlags,
-                                    pendingMessages);
+            Q_EMIT q->headersReceived(selectedMailBox, pendingUids, pendingSizes, pendingFlags, pendingMessages);
+            Q_EMIT q->headersReceived(selectedMailBox, pendingUids, pendingSizes, pendingAttributes, pendingFlags, pendingMessages);
         }
         if (!pendingMessages.isEmpty()) {
-            Q_EMIT q->messagesReceived(selectedMailBox,
-                                     pendingUids, pendingMessages);
-            Q_EMIT q->messagesReceived(selectedMailBox,
-                                     pendingUids, pendingAttributes,
-                                     pendingMessages);
+            Q_EMIT q->messagesReceived(selectedMailBox, pendingUids, pendingMessages);
+            Q_EMIT q->messagesReceived(selectedMailBox, pendingUids, pendingAttributes, pendingMessages);
         }
 
         pendingUids.clear();
@@ -100,14 +90,14 @@ FetchJob::FetchScope::FetchScope()
     : mode(FetchScope::Content)
     , changedSince(0)
     , qresync(false)
-{}
+{
+}
 
 FetchJob::FetchJob(Session *session)
     : Job(*new FetchJobPrivate(this, session, i18n("Fetch")))
 {
     Q_D(FetchJob);
-    connect(&d->emitPendingsTimer, SIGNAL(timeout()),
-            this, SLOT(emitPendings()));
+    connect(&d->emitPendingsTimer, SIGNAL(timeout()), this, SLOT(emitPendings()));
 }
 
 void FetchJob::setSequenceSet(const ImapSet &set)
@@ -211,7 +201,7 @@ void FetchJob::doStart()
         } else {
             parameters += "(BODY.PEEK[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO SUBJECT DATE)]";
             for (const QByteArray &part : qAsConst(d->scope.parts)) {
-                parameters += " BODY.PEEK[" + part + ".MIME] BODY.PEEK[" + part + "]"; //krazy:exclude=doublequote_chars
+                parameters += " BODY.PEEK[" + part + ".MIME] BODY.PEEK[" + part + "]"; // krazy:exclude=doublequote_chars
             }
             parameters += " FLAGS UID";
         }
@@ -250,22 +240,16 @@ void FetchJob::handleResponse(const Response &response)
 
     // We can predict it'll be handled by handleErrorReplies() so stop
     // the timer now so that result() will really be the last emitted signal.
-    if (!response.content.isEmpty() &&
-            d->tags.size() == 1 &&
-            d->tags.contains(response.content.first().toString())) {
+    if (!response.content.isEmpty() && d->tags.size() == 1 && d->tags.contains(response.content.first().toString())) {
         d->emitPendingsTimer.stop();
         d->emitPendings();
     }
 
     if (handleErrorReplies(response) == NotHandled) {
-        if (response.content.size() == 4 &&
-                response.content[1].toString() == "VANISHED") {
+        if (response.content.size() == 4 && response.content[1].toString() == "VANISHED") {
             const auto vanishedSet = ImapSet::fromImapSequenceSet(response.content[3].toString());
             Q_EMIT messagesVanished(vanishedSet);
-        } else if (response.content.size() == 4 &&
-                response.content[2].toString() == "FETCH" &&
-                response.content[3].type() == Response::Part::List) {
-
+        } else if (response.content.size() == 4 && response.content[2].toString() == "FETCH" && response.content[3].type() == Response::Part::List) {
             const qint64 id = response.content[1].toString().toLongLong();
             const QList<QByteArray> content = response.content[3].toList();
 
@@ -274,17 +258,15 @@ void FetchJob::handleResponse(const Response &response)
             bool shouldParseMessage = false;
             MessageParts parts;
 
-            for (QList<QByteArray>::ConstIterator it = content.constBegin();
-                    it != content.constEnd(); ++it) {
+            for (QList<QByteArray>::ConstIterator it = content.constBegin(); it != content.constEnd(); ++it) {
                 QByteArray str = *it;
                 ++it;
 
-                if (it == content.constEnd()) {   // Uh oh, message was truncated?
+                if (it == content.constEnd()) { // Uh oh, message was truncated?
                     qCWarning(KIMAP_LOG) << "FETCH reply got truncated, skipping.";
                     break;
                 }
 
-
                 if (str == "UID") {
                     d->pendingUids[id] = msg.uid = it->toLongLong();
                 } else if (str == "RFC822.SIZE") {
@@ -304,13 +286,13 @@ void FetchJob::handleResponse(const Response &response)
                         msg.flags << *it;
                     }
                 } else if (str == "X-GM-LABELS") {
-                    d->pendingAttributes.insert(id, { "X-GM-LABELS", *it });
+                    d->pendingAttributes.insert(id, {"X-GM-LABELS", *it});
                     msg.attributes.insert("X-GM-LABELS", *it);
                 } else if (str == "X-GM-THRID") {
-                    d->pendingAttributes.insert(id, { "X-GM-THRID", *it });
+                    d->pendingAttributes.insert(id, {"X-GM-THRID", *it});
                     msg.attributes.insert("X-GM-THRID", *it);
                 } else if (str == "X-GM-MSGID") {
-                    d->pendingAttributes.insert(id, { "X-GM-MSGID", *it });
+                    d->pendingAttributes.insert(id, {"X-GM-MSGID", *it});
                     msg.attributes.insert("X-GM-MSGID", *it);
                 } else if (str == "BODYSTRUCTURE") {
                     int pos = 0;
@@ -318,8 +300,8 @@ void FetchJob::handleResponse(const Response &response)
                     message->assemble();
                     d->pendingMessages[id] = message;
                     msg.message = message;
-                } else if (str.startsWith("BODY[")) {     //krazy:exclude=strings
-                    if (!str.endsWith(']')) {     // BODY[ ... ] might have been split, skip until we find the ]
+                } else if (str.startsWith("BODY[")) { // krazy:exclude=strings
+                    if (!str.endsWith(']')) { // BODY[ ... ] might have been split, skip until we find the ]
                         while (!(*it).endsWith(']')) {
                             ++it;
                         }
@@ -327,7 +309,7 @@ void FetchJob::handleResponse(const Response &response)
                     }
 
                     int index;
-                    if ((index = str.indexOf("HEADER")) > 0 || (index = str.indexOf("MIME")) > 0) {           // headers
+                    if ((index = str.indexOf("HEADER")) > 0 || (index = str.indexOf("MIME")) > 0) { // headers
                         if (str[index - 1] == '.') {
                             QByteArray partId = str.mid(5, index - 6);
                             if (!parts.contains(partId)) {
@@ -370,9 +352,7 @@ void FetchJob::handleResponse(const Response &response)
             // For the headers mode the message is built in several
             // steps, hence why we wait it to be done until putting it
             // in the pending queue.
-            if (d->scope.mode == FetchScope::Headers ||
-                    d->scope.mode == FetchScope::HeaderAndContent ||
-                    d->scope.mode == FetchScope::FullHeaders) {
+            if (d->scope.mode == FetchScope::Headers || d->scope.mode == FetchScope::HeaderAndContent || d->scope.mode == FetchScope::FullHeaders) {
                 d->pendingMessages[id] = message;
                 msg.message = message;
             }
@@ -392,13 +372,13 @@ void FetchJobPrivate::parseBodyStructure(const QByteArray &structure, int &pos,
 
     pos++;
 
-    if (structure[pos] != '(') {   // simple part
+    if (structure[pos] != '(') { // simple part
         pos--;
         parsePart(structure, pos, content);
     } else { // multi part
         content->contentType()->setMimeType("MULTIPART/MIXED");
         while (pos < structure.size() && structure[pos] == '(') {
-            auto *child = new KMime::Content;
+            auto child = new KMime::Content;
             content->addContent(child);
             parseBodyStructure(structure, pos, child);
             child->assemble();
@@ -407,7 +387,7 @@ void FetchJobPrivate::parseBodyStructure(const QByteArray &structure, int &pos,
         QByteArray subType = parseString(structure, pos);
         content->contentType()->setMimeType("MULTIPART/" + subType);
 
-        QByteArray parameters = parseSentence(structure, pos);   // FIXME: Read the charset
+        QByteArray parameters = parseSentence(structure, pos); // FIXME: Read the charset
         if (parameters.contains("BOUNDARY")) {
             content->contentType()->setBoundary(parameters.remove(0, parameters.indexOf("BOUNDARY") + 11).split('\"')[0]);
         }
@@ -419,7 +399,7 @@ void FetchJobPrivate::parseBodyStructure(const QByteArray &structure, int &pos,
             content->contentDisposition()->setDisposition(KMime::Headers::CDattachment);
         }
 
-        parseSentence(structure, pos);   // Ditch the body language
+        parseSentence(structure, pos); // Ditch the body language
     }
 
     // Consume what's left
@@ -445,14 +425,14 @@ void FetchJobPrivate::parsePart(const QByteArray &structure, int &pos, KMime::Co
 
     content->contentType()->setMimeType(mainType + '/' + subType);
 
-    parseSentence(structure, pos);   // Ditch the parameters... FIXME: Read it to get charset and name
-    parseString(structure, pos);   // ... and the id
+    parseSentence(structure, pos); // Ditch the parameters... FIXME: Read it to get charset and name
+    parseString(structure, pos); // ... and the id
 
     content->contentDescription()->from7BitString(parseString(structure, pos));
 
-    parseString(structure, pos);   // Ditch the encoding too
-    parseString(structure, pos);   // ... and the size
-    parseString(structure, pos);   // ... and the line count
+    parseString(structure, pos); // Ditch the encoding too
+    parseString(structure, pos); // ... and the size
+    parseString(structure, pos); // ... and the line count
 
     QByteArray disposition = parseSentence(structure, pos);
     if (disposition.contains("INLINE")) {
@@ -460,9 +440,9 @@ void FetchJobPrivate::parsePart(const QByteArray &structure, int &pos, KMime::Co
     } else if (disposition.contains("ATTACHMENT")) {
         content->contentDisposition()->setDisposition(KMime::Headers::CDattachment);
     }
-    if ((content->contentDisposition()->disposition() == KMime::Headers::CDattachment ||
-            content->contentDisposition()->disposition() == KMime::Headers::CDinline) &&
-            disposition.contains("FILENAME")) {
+    if ((content->contentDisposition()->disposition() == KMime::Headers::CDattachment
+         || content->contentDisposition()->disposition() == KMime::Headers::CDinline)
+        && disposition.contains("FILENAME")) {
         QByteArray filename = disposition.remove(0, disposition.indexOf("FILENAME") + 11).split('\"')[0];
         content->contentDisposition()->setFilename(QLatin1String(filename));
     }
@@ -532,14 +512,12 @@ QByteArray FetchJobPrivate::parseString(const QByteArray &structure, int &pos)
     if (structure[pos] == '"') {
         pos++;
         Q_FOREVER {
-        if (structure[pos] == '\\')
-            {
+            if (structure[pos] == '\\') {
                 pos += 2;
                 foundSlash = true;
                 continue;
             }
-            if (structure[pos] == '"')
-            {
+            if (structure[pos] == '"') {
                 result = structure.mid(start + 1, pos - start - 1);
                 pos++;
                 break;
@@ -548,19 +526,11 @@ QByteArray FetchJobPrivate::parseString(const QByteArray &structure, int &pos)
         }
     } else { // unquoted string
         Q_FOREVER {
-        if (structure[pos] == ' ' ||
-            structure[pos] == '(' ||
-            structure[pos] == ')' ||
-            structure[pos] == '[' ||
-            structure[pos] == ']' ||
-            structure[pos] == '\n' ||
-            structure[pos] == '\r' ||
-            structure[pos] == '"')
-            {
+            if (structure[pos] == ' ' || structure[pos] == '(' || structure[pos] == ')' || structure[pos] == '[' || structure[pos] == ']'
+                || structure[pos] == '\n' || structure[pos] == '\r' || structure[pos] == '"') {
                 break;
             }
-            if (structure[pos] == '\\')
-            {
+            if (structure[pos] == '\\') {
                 foundSlash = true;
             }
             pos++;
