@@ -9,18 +9,20 @@
 #include "response_p.h"
 #include "session_p.h"
 
-#include <KLocalizedString>
 #include "kimap_debug.h"
+#include <KLocalizedString>
 
 using namespace KIMAP;
 
 Job::Job(Session *session)
-    : KJob(session), d_ptr(new JobPrivate(session, i18n("Job")))
+    : KJob(session)
+    , d_ptr(new JobPrivate(session, i18n("Job")))
 {
 }
 
 Job::Job(JobPrivate &dd)
-    : KJob(dd.m_session), d_ptr(&dd)
+    : KJob(dd.m_session)
+    , d_ptr(&dd)
 {
 }
 
@@ -56,10 +58,9 @@ void Job::connectionLost()
 Job::HandlerResponse Job::handleErrorReplies(const Response &response)
 {
     Q_D(Job);
-//   qCDebug(KIMAP_LOG) << response.toString();
+    //   qCDebug(KIMAP_LOG) << response.toString();
 
-    if (!response.content.isEmpty() &&
-            d->tags.contains(response.content.first().toString())) {
+    if (!response.content.isEmpty() && d->tags.contains(response.content.first().toString())) {
         if (response.content.size() < 2) {
             setErrorText(i18n("%1 failed, malformed reply from the server.", d->m_name));
         } else if (response.content[1].toString() != "OK") {
@@ -67,7 +68,7 @@ Job::HandlerResponse Job::handleErrorReplies(const Response &response)
             setErrorText(i18n("%1 failed, server replied: %2", d->m_name, QLatin1String(response.toString().constData())));
         }
         d->tags.removeAll(response.content.first().toString());
-        if (d->tags.isEmpty()) {   // Only emit result when the last command returned
+        if (d->tags.isEmpty()) { // Only emit result when the last command returned
             emitResult();
         }
         return Handled;
